@@ -17,6 +17,7 @@ import synapse.lib.share as s_share
 import synapse.lib.config as s_config
 import synapse.lib.hashset as s_hashset
 import synapse.lib.httpapi as s_httpapi
+import synapse.lib.urlhelp as s_urlhelp
 import synapse.lib.msgpack as s_msgpack
 import synapse.lib.lmdbslab as s_lmdbslab
 import synapse.lib.slabseqn as s_slabseqn
@@ -496,7 +497,7 @@ class AxonApi(s_cell.CellApi, s_share.Share):  # type: ignore
 
     async def wput(self, sha256, url, params=None, headers=None, ssl=True, timeout=None):
         await self._reqUserAllowed(('axon', 'wput'))
-        return await self.cell.wput(sha256, url, params=None, headers=None, ssl=True, timeout=None)
+        return await self.cell.wput(sha256, url, params=params, headers=headers, ssl=ssl, timeout=timeout)
 
     async def metrics(self):
         '''
@@ -543,6 +544,10 @@ class Axon(s_cell.Cell):
             'description': 'An aiohttp-socks compatible proxy URL to use in the wget API.',
             'type': 'string',
         },
+        'tls:ca:dir': {
+            'description': 'An optional directory of CAs which are added to the TLS CA chain for wget and wput APIs.',
+            'type': 'string',
+        },
     }
 
     async def __anit__(self, dirn, conf=None):  # type: ignore
@@ -951,11 +956,21 @@ class Axon(s_cell.Cell):
         '''
         Stream a blob from the axon as the body of an HTTP request.
         '''
-        connector = None
         proxyurl = self.conf.get('http:proxy')
+        cadir = self.conf.get('tls:ca:dir')
+
+        connector = None
         if proxyurl is not None:
             connector = aiohttp_socks.ProxyConnector.from_url(proxyurl)
 
+        if ssl is False:
+            pass
+        elif cadir:
+            ssl = s_common.getSslCtx(cadir)
+        else:
+            # default aiohttp behavior
+            ssl = None
+
         atimeout = aiohttp.ClientTimeout(total=timeout)
 
         async with aiohttp.ClientSession(connector=connector, timeout=atimeout) as sess:
@@ -977,7 +992,7 @@ class Axon(s_cell.Cell):
                 raise
 
             except Exception as e:
-                logger.exception(f'Error streaming [{sha256}] to [{url}]')
+                logger.exception(f'Error streaming [{sha256}] to [{s_urlhelp.sanitizeUrl(url)}]')
                 exc = s_common.excinfo(e)
                 mesg = exc.get('errmsg')
                 if not mesg:
@@ -1026,15 +1041,25 @@ class Axon(s_cell.Cell):
         Returns:
             dict: A information dictionary containing the results of the request.
         '''
-        logger.debug(f'Wget called for [{url}].', extra=await self.getLogExtra(url=url))
+        logger.debug(f'Wget called for [{url}].', extra=await self.getLogExtra(url=s_urlhelp.sanitizeUrl(url)))
+
+        proxyurl = self.conf.get('http:proxy')
+        cadir = self.conf.get('tls:ca:dir')
 
         connector = None
-        proxyurl = self.conf.get('http:proxy')
         if proxyurl is not None:
             connector = aiohttp_socks.ProxyConnector.from_url(proxyurl)
 
         atimeout = aiohttp.ClientTimeout(total=timeout)
 
+        if ssl is False:
+            pass
+        elif cadir:
+            ssl = s_common.getSslCtx(cadir)
+        else:
+            # default aiohttp behavior
+            ssl = None
+
         async with aiohttp.ClientSession(connector=connector, timeout=atimeout) as sess:
 
             try:
@@ -1067,6 +1092,7 @@ class Axon(s_cell.Cell):
                 raise
 
             except Exception as e:
+                logger.exception(f'Failed to wget {s_urlhelp.sanitizeUrl(url)}')
                 exc = s_common.excinfo(e)
                 mesg = exc.get('errmsg')
                 if not mesg:
