@@ -436,6 +436,9 @@ class Cli(s_base.Base):
         except asyncio.CancelledError:
             self.printf('Cmd cancelled')
 
+        except s_exc.ParserExit as e:
+            pass # avoid duplicate print
+
         except Exception as e:
             exctxt = traceback.format_exc()
             self.printf(exctxt)
