@@ -72,7 +72,7 @@ class BackupTest(s_t_utils.SynTest):
             # Test corner case no-lmdbinfo
             with self.getTestDir() as dirn2:
                 with self.getLoggerStream('synapse.tools.backup') as stream:
-                    s_backup.txnbackup([], core.dirn, dirn2)
+                    s_backup.txnbackup({}, core.dirn, dirn2)
                     stream.seek(0)
                     self.isin('not copied', stream.read())
 
